[U-Boot] [PATCH v4 07/13] libfdt: Fix separator spelling

Maxime Ripard maxime.ripard at free-electrons.com
Tue Jul 5 10:26:40 CEST 2016


The function fdt_path_next_seperator had an obvious mispell. Fix it.

Signed-off-by: Maxime Ripard <maxime.ripard at free-electrons.com>
---
 lib/libfdt/fdt_ro.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/lib/libfdt/fdt_ro.c b/lib/libfdt/fdt_ro.c
index 503150ef1dc5..6b737b211d2e 100644
--- a/lib/libfdt/fdt_ro.c
+++ b/lib/libfdt/fdt_ro.c
@@ -140,12 +140,12 @@ int fdt_subnode_offset(const void *fdt, int parentoffset,
 }
 
 /*
  * Find the next of path seperator, note we need to search for both '/' and ':'
  * and then take the first one so that we do the right thing for e.g.
  * "foo/bar:option" and "bar:option/otheroption", both of which happen, so
  * first searching for either ':' or '/' does not work.
  */
-static const char *fdt_path_next_seperator(const char *path)
+static const char *fdt_path_next_separator(const char *path)
 {
 	const char *sep1 = strchr(path, '/');
 	const char *sep2 = strchr(path, ':');
@@ -168,7 +168,7 @@ int fdt_path_offset(const void *fdt, const char *path)
 
 	/* see if we have an alias */
 	if (*path != '/') {
-		const char *q = fdt_path_next_seperator(path);
+		const char *q = fdt_path_next_separator(path);
 
 		if (!q)
 			q = end;
@@ -188,7 +188,7 @@ int fdt_path_offset(const void *fdt, const char *path)
 			p++;
 		if (*p == '\0' || *p == ':')
 			return offset;
-		q = fdt_path_next_seperator(p);
+		q = fdt_path_next_separator(p);
 		if (!q)
 			q = end;
 
@@ -140,12 +140,12 @@ int fdt_subnode_offset(const void *fdt, int parentoffset,
 
 /*
- * Find the next of path seperator, note we need to search for both '/' and ':'
+ * Find the next of path separator, note we need to search for both '/' and ':'
  * and then take the first one so that we do the right thing for e.g.
  * "foo/bar:option" and "bar:option/otheroption", both of which happen, so
-- 
2.9.0



More information about the U-Boot mailing list